{% extends 'layout.html' %}

{% block content %}
<div class="jumbotron">
    <h1>Welcome to DJango Project Development</h1>
    <h2>We're done. Project submitted. We can go back to Florida now.</h2>
    <h3>Toodles!</h3>
</div>
{% endblock %}