{% extends 'layout.html' %}

{% block content %}
<div class="container" style="margin-top: 20px;">
    <table class="table table-bordered table-striped">
        <thead class="thead-dark">
            <tr>
                <th>User ID</th>
                <th>Name</th>
                <th>Email</th>
                <th>Manage</th>
            </tr>
        </thead>
        <tbody>
            {% for item in list %}
                <tr>
                    <td>{{item.id}}</td>
                    <td>{{item.name}}</td>
                    <td>{{item.email}}</td>
                    <td>
                        <a href="{% url 'singleuser' item.id %}" class="btn btn-primary btn-sm">View</a>
                        <a href="{% url 'edituser' item.id %}" class="btn btn-warning btn-sm">Update</a>
                        <a href="{% url 'deleteuser' item.id %}" class="btn btn-danger btn-sm">Delete</a>
                    </td>
                </tr>
            {% endfor %}
        </tbody>
        <tfoot>
            <tr>
                <th>User ID</th>
                <th>Name</th>
                <th>Email</th>
                <th>Manage</th>
            </tr>
        </tfoot>
    </table>
</div>
{% endblock %}